Index: branches/eam_branches/ipp-20121219/ippToPsps/test/fulltest.sh
===================================================================
--- branches/eam_branches/ipp-20121219/ippToPsps/test/fulltest.sh	(revision 35051)
+++ branches/eam_branches/ipp-20121219/ippToPsps/test/fulltest.sh	(revision 35063)
@@ -25,13 +25,13 @@
 # mkgpc1.sh user localhost eam eam
 
-set mkgpc1      = 0
-set initdb      = 0
-set mkdummy     = 0
-set initscratch = 0
-set initbatch   = 0
-set camqueue    = 0
-set cambatch    = 0
-set stackqueue  = 0
-set stackbatch  = 0
+set mkgpc1       = 1
+set initdb       = 1
+set mkdummy      = 1
+set initscratch  = 1
+set initbatch    = 1
+set camqueue     = 1
+set cambatch     = 1
+set stackqueue   = 1
+set stackbatch   = 1
 set objectqueue  = 1
 set objectbatch  = 1
@@ -56,5 +56,5 @@
 # create a dummy config so setupScratchDb.py does not fail
 if ($mkdummy) then
-  ippjython queue.py edit <<EOF
+  ippjython queue.py -test edit <<EOF
 dummy
 none
@@ -80,4 +80,5 @@
 0
 1
+0
 EOF
 endif
@@ -87,20 +88,20 @@
 
   # create the database (ignore failure if it already exists)
-  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_test_scratch"
+  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_test_scratch1"
   # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch2"
   # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch3"
 
-  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test_scratch"
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test_scratch1"
   # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch2"
   # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch3"
 
-  ippjython setupScratchDb.py dummy ipptopsps_test_scratch
-  # ippjython setupScratchDb.py dummy ipptopsps_scratch2
-  # ippjython setupScratchDb.py dummy ipptopsps_scratch3
+  ippjython setupScratchDb.py -test dummy ipptopsps_test_scratch1
+  # ippjython setupScratchDb.py -test dummy ipptopsps_scratch2
+  # ippjython setupScratchDb.py -test dummy ipptopsps_scratch3
 endif
 
 # this code is sensitive to a previously existing database?
 if ($camqueue) then
-  ippjython queue.py edit <<EOF
+  ippjython queue.py -test edit <<EOF
 $queuename
 test_ds
@@ -126,4 +127,5 @@
 0
 1
+0
 y
 y
@@ -133,10 +135,10 @@
 if ($initbatch) then
   rm -rf $OUTDIR/IN
-  ippjython loader.py $queuename init
+  ippjython loader.py -test $queuename init
 endif
 
 if ($cambatch) then
   rm -rf $OUTDIR/P2
-  ippjython loader.py $queuename once
+  ippjython loader.py -test $queuename once
 endif
 
@@ -146,5 +148,5 @@
     set stackqueuename = $queuename\_stk
   endif
-  ippjython queue.py edit <<EOF
+  ippjython queue.py -test edit <<EOF
 $stackqueuename
 test_ds
@@ -170,4 +172,5 @@
 0
 1
+0
 y
 y
@@ -180,5 +183,5 @@
   endif
   rm -rf $OUTDIR/ST
-  ippjython loader.py $stackqueuename once
+  ippjython loader.py -test $stackqueuename once
 endif
 
@@ -188,5 +191,5 @@
     set objectqueuename = $queuename\_obj
   endif
-  ippjython queue.py edit <<EOF
+  ippjython queue.py -test edit <<EOF
 $objectqueuename
 test_ds
@@ -212,4 +215,5 @@
 1
 1
+0
 y
 y
@@ -222,5 +226,5 @@
   endif
   rm -rf $OUTDIR/OB
-  ippjython loader.py $objectqueuename once
-endif
-
+   ippjython loader.py -test $objectqueuename once
+endif
+
Index: branches/eam_branches/ipp-20121219/ippToPsps/test/mkgpc1data.dvo
===================================================================
--- branches/eam_branches/ipp-20121219/ippToPsps/test/mkgpc1data.dvo	(revision 35051)
+++ branches/eam_branches/ipp-20121219/ippToPsps/test/mkgpc1data.dvo	(revision 35063)
@@ -4,4 +4,5 @@
 
 if (not($?VERBOSE)) set VERBOSE = 0
+if (not($?PARALLEL)) set PARALLEL = 0
 
 ## this script must be run in this directory, output data goes to 'testdata'
@@ -199,4 +200,16 @@
   end
 
+  if ($PARALLEL)
+    $hostname = `hostname`
+    exec rm -f $catdir/HostTable.dat
+    output $catdir/HostTable.dat
+    echo "# ID Hostname Catdir"
+    echo " 1 $hostname $catdir.p1"
+    echo " 2 $hostname $catdir.p2"
+    echo " 3 $hostname $catdir.p3"
+    output stdout
+    exec dvodist -out $catdir
+  end
+
   # for i 0 $offset:n
   #   tapOK {abs(Mcal[$i] - Mcal[0] - $offset:$i) < 0.001} "Mcal $i"
@@ -239,4 +252,16 @@
 
     exec addstar -D CATDIR $catdir -D CAMERA simtest $cmffile -D CATFORMAT $2 -quick-airmass
+  end
+
+  if ($PARALLEL)
+    $hostname = `hostname`
+    exec rm -f $catdir/HostTable.dat
+    output $catdir/HostTable.dat
+    echo "# ID Hostname Catdir"
+    echo " 1 $hostname $catdir.p1"
+    echo " 2 $hostname $catdir.p2"
+    echo " 3 $hostname $catdir.p3"
+    output stdout
+    exec dvodist -out $catdir
   end
 
@@ -358,4 +383,9 @@
 
 if ($SCRIPT)
+  if ($argv:n > 0)
+    if ("$argv:0" == "-parallel")
+      $PARALLEL = 1
+    end
+  end
   mkfull
   exit 0
Index: branches/eam_branches/ipp-20121219/ippToPsps/test/partest.sh
===================================================================
--- branches/eam_branches/ipp-20121219/ippToPsps/test/partest.sh	(revision 35063)
+++ branches/eam_branches/ipp-20121219/ippToPsps/test/partest.sh	(revision 35063)
@@ -0,0 +1,230 @@
+#!/bin/csh -f
+
+set stackqueuename = 0
+if ($#argv > 0) then
+  set stackqueuename = $1
+  echo "stackqueue: $stackqueuename"
+endif
+
+set objectqueuename = 0
+if ($#argv > 0) then
+  set stackqueuename = $1
+  echo "stackqueue: $stackqueuename"
+endif
+
+# a bit crude : get the datadir path by interpollation of the PATH element for psconfig
+foreach f ( `echo $PATH | tr : ' '` )
+  echo $f | grep $PSCONFDIR > /dev/null
+  if ($status) continue
+  set datadir = `echo $f | sed s/bin\$/share/`
+  break
+end
+setenv IPPTOPSPS_DATA $datadir/ipptopsps
+
+# before running this test, you must have a mysql user:
+# mkgpc1.sh user localhost eam eam
+
+set mkgpc1       = 0
+set initdb       = 0
+set mkdummy      = 0
+set initscratch  = 0
+set initbatch    = 0
+set camqueue     = 0
+set cambatch     = 0
+set stackqueue   = 1
+set stackbatch   = 1
+set objectqueue  = 1
+set objectbatch  = 1
+
+set OUTDIR = "testdata"
+set queuename = "test"
+
+if ($mkgpc1) then
+  mkgpc1data.dvo -parallel
+endif
+
+# create the ipptopsps database
+if ($initdb) then 
+
+  # does the database already exist?
+  # XXX this command will blow away an existing database!!
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test"
+  mysql -h localhost -u dvo -pdvo ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
+
+endif
+
+# create a dummy config so setupScratchDb.py does not fail
+if ($mkdummy) then
+  ippjython queue.py -test edit <<EOF
+dummy
+none
+IPP_PSPS
+0
+none
+none
+0
+0
+0
+0
+1
+none
+0
+0
+1
+1
+2001-01-01 00:00:00.0
+NONE
+NONE
+1
+0
+0
+1
+0
+EOF
+endif
+
+# re-create the ipptopsps database
+if ($initscratch) then 
+
+  # create the database (ignore failure if it already exists)
+  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_test_scratch1"
+  # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch2"
+  # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch3"
+
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test_scratch1"
+  # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch2"
+  # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch3"
+
+  ippjython setupScratchDb.py -test dummy ipptopsps_test_scratch1
+  # ippjython setupScratchDb.py -test dummy ipptopsps_scratch2
+  # ippjython setupScratchDb.py -test dummy ipptopsps_scratch3
+endif
+
+# this code is sensitive to a previously existing database?
+if ($camqueue) then
+  ippjython queue.py -test edit <<EOF
+$queuename
+test_ds
+IPP_PSPS
+0
+catdir.cam
+$OUTDIR/catdir.cam
+9
+11
+19
+21
+2
+$OUTDIR
+0
+0
+1
+1
+2012-12-10 00:00:00.0
+3PI
+3PI
+1
+0
+0
+1
+1
+y
+y
+EOF
+endif
+
+if ($initbatch) then
+  rm -rf $OUTDIR/IN
+  ippjython loader.py -test $queuename init
+endif
+
+if ($cambatch) then
+  rm -rf $OUTDIR/P2
+  ippjython loader.py -test $queuename once
+endif
+
+# this code is sensitive to a previously existing database?
+if ($stackqueue) then
+  if ($stackqueuename == 0) then
+    set stackqueuename = $queuename\_stk
+  endif
+  ippjython queue.py -test edit <<EOF
+$stackqueuename
+test_ds
+IPP_PSPS
+0
+catdir.stk
+$OUTDIR/catdir.stk
+9
+11
+19
+21
+2
+$OUTDIR
+0
+0
+1
+1
+2012-12-10 00:00:00.0
+3PI
+3PI
+0
+1
+0
+1
+1
+y
+y
+EOF
+endif
+
+if ($stackbatch) then
+  if ($stackqueuename == 0) then
+    set stackqueuename = $queuename\_stk
+  endif
+  rm -rf $OUTDIR/ST
+  ippjython loader.py -test $stackqueuename once
+endif
+
+# this code is sensitive to a previously existing database?
+if ($objectqueue) then
+  if ($objectqueuename == 0) then
+    set objectqueuename = $queuename\_obj
+  endif
+  ippjython queue.py -test edit <<EOF
+$objectqueuename
+test_ds
+IPP_PSPS
+0
+catdir.stk
+$OUTDIR/catdir.stk
+9
+11
+19
+21
+2
+$OUTDIR
+0
+0
+1
+1
+2012-12-10 00:00:00.0
+3PI
+3PI
+0
+0
+1
+1
+0
+y
+y
+EOF
+endif
+
+if ($objectbatch) then
+  if ($objectqueuename == 0) then
+    set objectqueuename = $queuename\_obj
+  endif
+  rm -rf $OUTDIR/OB
+   ippjython loader.py -test $objectqueuename once
+endif
+
Index: branches/eam_branches/ipp-20121219/ippToPsps/test/sastest.sh
===================================================================
--- branches/eam_branches/ipp-20121219/ippToPsps/test/sastest.sh	(revision 35051)
+++ branches/eam_branches/ipp-20121219/ippToPsps/test/sastest.sh	(revision 35063)
@@ -19,11 +19,11 @@
 # mkgpc1.sh user localhost eam eam
 
-set mkgpc1      = 1
-set initdb      = 1
-set mkdummy     = 1
-set initscratch = 1
-set initbatch   = 0
-set camqueue    = 0
-set cambatch    = 0
+set mkgpc1      = 0
+set initdb      = 0
+set mkdummy     = 0
+set initscratch = 0
+set initbatch   = 1
+set camqueue    = 1
+set cambatch    = 1
 set stackqueue  = 1
 set stackbatch  = 1
@@ -41,6 +41,6 @@
   # does the database already exist?
   # XXX this command will blow away an existing database!!
-  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps"
-  mysql -h localhost -u dvo -pdvo ipptopsps < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_test"
+  mysql -h localhost -u dvo -pdvo ipptopsps_test < $IPPTOPSPS_DATA/ippToPspsDbSchema.sql
 
 endif
@@ -48,5 +48,5 @@
 # create a dummy config so setupScratchDb.py does not fail
 if ($mkdummy) then
-  ippjython queue.py edit <<EOF
+  ippjython queue.py -test edit <<EOF
 dummy
 none
@@ -72,4 +72,6 @@
 0
 1
+0
+1
 EOF
 endif
@@ -79,20 +81,20 @@
 
   # create the database (ignore failure if it already exists)
-  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch"
+  mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch1"
   # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch2"
   # mysql -h localhost -u dvo -pdvo -e "drop database ipptopsps_scratch3"
 
-  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch"
+  mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch1"
   # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch2"
   # mysql -h localhost -u dvo -pdvo -e "create database ipptopsps_scratch3"
 
-  ippjython setupScratchDb.py dummy ipptopsps_scratch
-  # ippjython setupScratchDb.py dummy ipptopsps_scratch2
-  # ippjython setupScratchDb.py dummy ipptopsps_scratch3
+  ippjython setupScratchDb.py -test dummy ipptopsps_scratch1
+  # ippjython setupScratchDb.py -test dummy ipptopsps_scratch2
+  # ippjython setupScratchDb.py -test dummy ipptopsps_scratch3
 endif
 
 # this code is sensitive to a previously existing database?
 if ($camqueue) then
-  ippjython queue.py edit <<EOF
+  ippjython queue.py -test edit <<EOF
 $queuename
 test_ds
@@ -118,4 +120,6 @@
 0
 1
+0
+1
 y
 y
@@ -124,9 +128,9 @@
 
 if ($initbatch) then
-  ippjython loader.py $queuename init
+  ippjython loader.py -test $queuename init
 endif
 
 if ($cambatch) then
-  ippjython loader.py $queuename once
+  ippjython loader.py -test $queuename once
 endif
 
@@ -136,5 +140,5 @@
     set stackqueuename = $queuename\_stk
   endif
-  ippjython queue.py edit <<EOF
+  ippjython queue.py -test edit <<EOF
 $stackqueuename
 test_ds
@@ -160,4 +164,6 @@
 0
 1
+0
+1
 y
 y
@@ -169,5 +175,5 @@
     set stackqueuename = $queuename\_stk
   endif
-  ippjython loader.py $stackqueuename once
+  ippjython loader.py -test $stackqueuename once
 endif
 
